<?php
/*
Plugin Name: PJW WP Cache Inspect
Plugin URI: http://blog.ftwr.co.uk/wordpress/wp-cache-inspect/
Description: Enables you to inspect how the builtin cache is working.
Author: Peter Westwood
Version: 0.5
Author URI: http://blog.ftwr.co.uk/
*/

/*  Copyright 2005  Peter Westwood  (email : peter.westwood@ftwr.co.uk)

    This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

class pjw_wp_cache_inspect
{
	//Constructor
	function pjw_wp_cache_inspect()
	{
		$plugin_filename= str_replace('\\', '/', preg_replace('/^.*wp-content[\\\\\/]plugins[\\\\\/]/', '', __FILE__)); 
		add_action('activate_'.$plugin_filename , array(&$this,'activate'));
		add_action('deactivate_'.$plugin_filename , array(&$this,'deactivate'));
		add_action('admin_menu', array(&$this,'admin_menu'));
		add_action('wp_head', array(&$this,'wp_head'));
		add_action('wp_footer', array(&$this,'wp_footer'));
	}
	
	function activate()
	{
		global $wp_roles;
		$wp_roles->add_cap('administrator','manage_cache');
		//Workaround this - http://trac.wordpress.org/ticket/2387
		wp_cache_close();
	}

	function deactivate()
	{
		global $wp_roles;
		$wp_roles->remove_cap('administrator','manage_cache');
		//Workaround this - http://trac.wordpress.org/ticket/2387
		wp_cache_close();
	}
	
	function admin_menu()
	{
		add_management_page('Manage Cache','Cache','manage_cache','pjw-wp-cache-inspect',array(&$this,'display_page'));
	}

	function wp_head()
	{
		if (current_user_can('manage_cache'))
		{
		?>
		<style type="text/css" media="screen">
		/* Begin pjw_wp_cache_manage CSS */
		.transparent {
		filter:alpha(opacity=50);
		opacity: 0.5;
		-moz-opacity:0.5;
		}
		#cachestats
		{
			position:absolute;
			top: 10px;
			right:10px;
			border: 1px solid black;
			background: #eee;
			text-align:left;
			padding:5px;	
		}
		/* End pjw_wp_cache_manage CSS */
		</style>
		<?php
		}
	}

	function wp_footer()
	{
		if (current_user_can('manage_cache'))
		{
			global $wp_object_cache,$wpdb;
			echo "<p class='transparent' id='cachestats'>";
        	echo "<strong>Cold Cache Hits:</strong> {$wp_object_cache->cold_cache_hits}<br/>";
			echo "<strong>Warm Cache Hits:</strong> {$wp_object_cache->warm_cache_hits}<br/>";
			echo "<strong>Cache Misses:</strong> {$wp_object_cache->cache_misses}<br/>";
			echo "<strong>DB Queries:</strong> {$wpdb->num_queries}<br/>";
			echo "<strong>Loaded data:</strong><br/>";
			foreach ($wp_object_cache->cache as $group => $cache)
			{
				echo "<strong>$group</strong> - ". count($cache)  ." items <br/>";
			}
			echo "</p>";
		}
	}

	function display_page()
	{
		if (isset($_POST["action"]) && "clearcache" == $_POST["action"])
		{
			if (current_user_can('manage_cache'))
			{
				wp_cache_flush();
				?>
				<div id="message" class="updated fade"><p>Cache cleared.</p></div>
				<?php
			} else {
				?>
				<div id="message" class="updated fade"><p>Cache not cleared - you don't have the privilidges to do this!.</p></div>
				<?php
			}
		}
	?>
	<div class="wrap">
	<h2>Wordpress Cache Management</h2>
	<form name="clearcache" method="post" action="edit.php?page=pjw-wp-cache-inspect">
	<input type="hidden" name="action" value="clearcache" />
	<input type="submit" value="Clear the cache" />
	</form>	
	</div>
	<?php
	}
}

/* Initialise outselves */
$pjw_wp_cache_inspect = new pjw_wp_cache_inspect;

